TestMicrophoneApi class abstract

Constructors

TestMicrophoneApi()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

create() → IdMessage
dispose(IdMessage arg) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start(IdMessage arg) → void
stop(IdMessage arg) → RecordingMessage
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

setup(TestMicrophoneApi? api) → void